==> earlgrey-4.0.2-h85dcccf_0.tar.bz2: share/earlgrey-4.0.2-0/build_env_setup.sh <==
export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export ARCH="64"
export PREFIX="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export BUILD_PREFIX="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_build_env"
export SYS_PREFIX="/opt/mambaforge/envs/bioconda"
export SYS_PYTHON="/opt/mambaforge/envs/bioconda/bin/python3.8"
export SUBDIR="osx-64"
export build_platform="osx-64"
export SRC_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/work"
export ROOT="/opt/mambaforge/envs/bioconda"
export CONDA_PY="39"
export PY3K="1"
export PY_VER="3.9"
export STDLIB_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.9"
export SP_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.9/site-packages"
export NPY_VER="1.21"
export CONDA_NPY="121"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.32"
export CONDA_PERL="5.32"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="4.3.*"
export CONDA_R="4.3.*"
export PKG_NAME="earlgrey"
export PKG_VERSION="4.0.2"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/Users/runner/work/1/s/recipes/earlgrey"
export CPU_COUNT="3"
export LANG="en_US.UTF-8"
export LC_ALL="en_US.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_build_env/bin:/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin:/opt/mambaforge/envs/bioconda/bin:/opt/mambaforge/condabin:/opt/mambaforge/bin:/usr/local/lib/ruby/gems/3.0.0/bin:/usr/local/opt/ruby@3.0/bin:/usr/local/opt/pipx_bin:/Users/runner/.cargo/bin:/usr/local/opt/curl/bin:/usr/local/bin:/usr/local/sbin:/Users/runner/bin:/Users/runner/.yarn/bin:/Users/runner/Library/Android/sdk/tools:/Users/runner/Library/Android/sdk/platform-tools:/Library/Frameworks/Python.framework/Versions/Current/bin:/Library/Frameworks/Mono.framework/Versions/Current/Commands:/usr/bin:/bin:/usr/sbin:/sbin:/Users/runner/.dotnet/tools:/Users/runner/.ghcup/bin"
export HOME="/Users/runner"
export PKG_CONFIG_PATH="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="x86_64"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export BUILD="x86_64-apple-darwin13.4.0"
export ignore_build_only_deps="{'numpy', 'python'}"
export zip_keys="[['c_compiler_version', 'cxx_compiler_version', 'fortran_compiler_version'], ['arrow_cpp', 'libarrow'], ['python', 'numpy', 'python_impl']]"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('boost', {'max_pin': 'x.x.x'}), ('boost-cpp', {'max_pin': 'x.x.x'}), ('flann', {'max_pin': 'x.x.x'}), ('graphviz', {'max_pin': 'x'}), ('libsvm', {'max_pin': 'x'}), ('netcdf-cxx4', {'max_pin': 'x.x'}), ('occt', {'max_pin': 'x.x'}), ('poppler', {'max_pin': 'x.x'}), ('vlfeat', {'max_pin': 'x.x.x'}), ('htslib', {'max_pin': 'x.x'}), ('bamtools', {'max_pin': 'x.x.x'})])"
export extend_keys="{'ignore_build_only_deps', 'pin_run_as_build', 'extend_keys', 'ignore_version'}"
export console_bridge="1.0"
export grpc_cpp="1.52"
export coin_or_cgl="0.60"
export fortran_compiler="gfortran"
export libprotobuf="3.21"
export icu="70"
export expat="2"
export pcre="8"
export pcre2="10.40"
export gsoap="2.8.123"
export boost="1.78.0"
export libssh2="1"
export hdf5="1.12.2"
export krb5="1.19"
export elfutils="0.189"
export pulseaudio="16.1"
export libdap4="3.20.6"
export channel_sources="conda-forge,bioconda,defaults"
export libtiff="4.4"
export libthrift="0.18.1"
export arb="2.23"
export gst_plugins_base="1.22"
export libunwind="1.6"
export libiconv="1"
export glog="0.6"
export antic="0.2"
export fontconfig="2"
export cuda_compiler_version_min="None"
export libcurl="8"
export sdl2_mixer="2"
export attr="2.5"
export thrift_cpp="0.18.1"
export libcrc32c="1.1"
export log4cxx="0.11.0"
export p11_kit="0.24"
export coin_or_utils="2.11"
export petsc="3.17"
export x265="3.5"
export libssh="0.10"
export go_compiler="go-nocgo"
export poppler="22.12"
export ffmpeg="4.4"
export openmpi="4"
export gflags="2.2"
export zlib="1.2"
export lz4_c="1.9.3"
export openblas="0.3.*"
export aws_c_s3="0.2.8"
export libflatsurf="3"
export tiledb="2.13"
export qtkeychain="0.13"
export gdal="3.6"
export slepc="3.17"
export libblas="3.9 *netlib"
export libpcap="1.10"
export superlu_dist="7.1.1"
export svt_av1="1.4.1"
export cudnn="undefined"
export target_gobin="${PREFIX}/bin/"
export eclib="20230424"
export nlopt="2.7"
export gsl="2.7"
export singular="4.2.1.p3"
export aws_sdk_cpp="1.10.57"
export libhwy="1.0"
export volk="3.0"
export libcblas="3.9 *netlib"
export arpack="3.7"
export glib="2"
export VERBOSE_CM="VERBOSE=1"
export ruby="2.6"
export abseil_cpp="20220623.0"
export mkl_devel="2022"
export libblitz="1.0.2"
export coin_or_osi="0.108"
export c_compiler="clang"
export mumps_mpi="5.2.1"
export pcl="1.13.0"
export libsecret="0.18"
export json_c="0.16"
export ucx="1.14.0"
export spdlog="1.11"
export lerc="4"
export cran_mirror="https://cran.r-project.org"
export libintervalxt="3"
export harfbuzz="6"
export google_cloud_cpp_common="0.25.0"
export libv8="8.9.83"
export jasper="2"
export libhugetlbfs="2"
export libopencv="4.7.0"
export mkl="2022"
export orc="1.8.3"
export target_goarch="amd64"
export imath="3.1.7"
export tbb_devel="2021"
export assimp="5.2.5"
export glpk="5.0"
export giflib="5.2"
export openssl="3"
export libflint="2.9"
export cxx_compiler="clangxx"
export libevent="2.1.10"
export davix="0.8"
export aws_c_common="0.8.17"
export bzip2="1"
export _libgcc_mutex="0.1 conda_forge"
export geotiff="1.7.1"
export qt="5.12"
export sdl2_ttf="2"
export geos="3.11.1"
export libgrpc="1.52"
export zstd="1.5"
export cuda_compiler_version="None"
export libvips="8"
export re2="2023.02.02"
export macos_machine="x86_64-apple-darwin13.4.0"
export pybind11_abi="4"
export aws_c_mqtt="0.8.6"
export uhd="4.4.0"
export libcint="5.2"
export coin_or_cbc="2.10"
export google_cloud_cpp="2.10.0"
export scotch="6.0.9"
export petsc4py="3.17"
export poco="1.12.4"
export graphviz="8"
export proj="9.1.0"
export libdeflate="1.18"
export kealib="1.5"
export mpg123="1.31"
export liblapacke="3.9 *netlib"
export jpeg="9"
export libeantic="1"
export netcdf_fortran="4.5"
export VERBOSE_AT="V=1"
export openturns="1.20"
export freetype="2"
export c_ares="1"
export capnproto="0.10.2"
export nettle="3.8"
export zlib_ng="2.0"
export readline="8"
export libsqlite="3"
export gdk_pixbuf="2"
export flann="1.9.1"
export libgoogle_cloud="2.10.0"
export llvm_openmp="15"
export boost_cpp="1.78.0"
export pari="2.15.* *_pthread"
export root_base="6.26.10"
export blas_impl="blis"
export rust_compiler="rust"
export libabseil="20230125"
export tk="8.6"
export srm_ifce="1.24.6"
export aws_crt_cpp="0.19.9"
export nss="3"
export postgresql="15"
export xrootd="5"
export xerces_c="3.2"
export aws_c_event_stream="0.2.20"
export target_platform="osx-64"
export libiio="0"
export dbus="1"
export ipopt="3.14.11"
export libsvm="325"
export mimalloc="2.1.1"
export libev="4.33"
export cutensor="1"
export r_base="4.3.*"
export isl="0.25"
export libxml2="2.11.*"
export netcdf_cxx4="4.3"
export cuda_compiler="None"
export channel_targets="bioconda main"
export libmatio="1.5.21"
export dcap="2.47"
export lcms="2"
export cairo="1"
export libwebp_base="1"
export libsentencepiece="0.1.97"
export curl="8"
export sqlite="3"
export gfal2="2.21"
export bamtools="2.5.1"
export postgresql_plpython="15"
export aws_checksums="0.1.14"
export libarchive="3.6"
export libsndfile="1.2"
export libwebp="1"
export libuuid="2"
export gf2x="1.3"
export libffi="3.4"
export openjpeg="2"
export libspatialindex="1.9.3"
export alsa_lib="1.2.8"
export libraw="0.21"
export coin_or_clp="1.17"
export s2n="1.3.42"
export ncurses="6"
export hdf4="4.2.15"
export snappy="1"
export gnutls="3.7"
export libidn2="2"
export mpfr="4"
export cgo_compiler="go-cgo"
export aom="3.5"
export libjpeg_turbo="2"
export pango="1.50"
export vtk="9.2.5"
export aws_c_sdkutils="0.1.9"
export target_goos="darwin"
export pytorch="1.13"
export metis="5.1"
export sdl2="2"
export wxwidgets="3.2"
export libpq="15"
export xz="5"
export mumps_seq="5.2.1"
export aws_c_http="0.7.7"
export libkml="1.3"
export sdl2_net="2"
export cpu_optimization_target="nocona"
export rocksdb="6.10"
export pixman="0"
export cfitsio="4.1.0"
export librdkafka="1.9"
export nodejs="14"
export aws_c_auth="0.6.26"
export starlink_ast="9.2.7"
export lzo="2"
export ccr="1.3"
export libabseil_static="20220623.0"
export openexr="3.1"
export coincbc="2.10"
export gct="6.2.1629922860"
export libgit2="1.6"
export googleapis_cpp="0.10"
export slepc4py="3.17"
export libmicrohttpd="0.9"
export jsoncpp="1.9.5"
export librsvg="2"
export wcslib="7.7"
export libavif="0.11.1"
export libxsmm="1"
export exiv2="0.27"
export occt="7.7"
export gstreamer="1.22"
export ntl="11.4.3"
export fmt="9"
export liblapack="3.9 *netlib"
export gmp="6"
export libnetcdf="4.8.1"
export tinyxml2="9"
export tbb="2021"
export nccl="2"
export sdl2_image="2"
export glew="2.1"
export sox="14.4.2"
export libpng="1.6"
export mpich="4"
export ptscotch="6.0.9"
export zeromq="4.3.4"
export nspr="4"
export gnuradio_core="3.10.6"
export libgdal="3.6"
export aws_c_io="0.13.21"
export openh264="2.3.1"
export suitesparse="5"
export libaec="1"
export urdfdom="3.1"
export fftw="3"
export libzip="1"
export x264="1!164.*"
export aws_c_cal="0.5.26"
export vlfeat="0.9.21"
export soapysdr="0.8"
export libexactreal="3"
export zfp="1.0"
export c_compiler_version="15"
export cxx_compiler_version="15"
export fortran_compiler_version="12"
export python_impl="cpython"
export arrow_cpp="11.0.0"
export libarrow="11.0.0"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/mambaforge/envs/bioconda/bin/python3.8' -m conda shell.bash hook)"
conda activate  "/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1701368922041/_build_env"

==> earlgrey-4.0.3-h85dcccf_0.tar.bz2: share/earlgrey-4.0.3-0/build_env_setup.sh <==
export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export ARCH="64"
export PREFIX="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place"
export BUILD_PREFIX="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_build_env"
export SYS_PREFIX="/opt/mambaforge/envs/bioconda"
export SYS_PYTHON="/opt/mambaforge/envs/bioconda/bin/python3.8"
export SUBDIR="osx-64"
export build_platform="osx-64"
export SRC_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/work"
export ROOT="/opt/mambaforge/envs/bioconda"
export CONDA_PY="39"
export PY3K="1"
export PY_VER="3.9"
export STDLIB_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.9"
export SP_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/python3.9/site-packages"
export NPY_VER="1.21"
export CONDA_NPY="121"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.32"
export CONDA_PERL="5.32"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="4.3.*"
export CONDA_R="4.3.*"
export PKG_NAME="earlgrey"
export PKG_VERSION="4.0.3"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/Users/runner/work/1/s/recipes/earlgrey"
export CPU_COUNT="4"
export LANG="en_US.UTF-8"
export LC_ALL="en_US.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_build_env/bin:/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/bin:/opt/mambaforge/envs/bioconda/bin:/opt/mambaforge/condabin:/opt/mambaforge/bin:/usr/local/lib/ruby/gems/3.0.0/bin:/usr/local/opt/ruby@3.0/bin:/usr/local/opt/pipx_bin:/Users/runner/.cargo/bin:/usr/local/opt/curl/bin:/usr/local/bin:/usr/local/sbin:/Users/runner/bin:/Users/runner/.yarn/bin:/Users/runner/Library/Android/sdk/tools:/Users/runner/Library/Android/sdk/platform-tools:/Library/Frameworks/Python.framework/Versions/Current/bin:/Library/Frameworks/Mono.framework/Versions/Current/Commands:/usr/bin:/bin:/usr/sbin:/sbin:/Users/runner/.dotnet/tools:/Users/runner/.ghcup/bin:/Users/runner/hostedtoolcache/stack/2.13.1/x64"
export HOME="/Users/runner"
export PKG_CONFIG_PATH="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="x86_64"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export BUILD="x86_64-apple-darwin13.4.0"
export zip_keys="[['python', 'numpy', 'python_impl'], ['c_compiler_version', 'cxx_compiler_version', 'fortran_compiler_version'], ['arrow_cpp', 'libarrow']]"
export extend_keys="{'ignore_version', 'extend_keys', 'ignore_build_only_deps', 'pin_run_as_build'}"
export ignore_build_only_deps="{'numpy', 'python'}"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('boost', {'max_pin': 'x.x.x'}), ('boost-cpp', {'max_pin': 'x.x.x'}), ('flann', {'max_pin': 'x.x.x'}), ('graphviz', {'max_pin': 'x'}), ('libsvm', {'max_pin': 'x'}), ('netcdf-cxx4', {'max_pin': 'x.x'}), ('occt', {'max_pin': 'x.x'}), ('poppler', {'max_pin': 'x.x'}), ('vlfeat', {'max_pin': 'x.x.x'}), ('htslib', {'max_pin': 'x.x'}), ('bamtools', {'max_pin': 'x.x.x'})])"
export cutensor="1"
export libdeflate="1.18"
export volk="3.0"
export srm_ifce="1.24.6"
export libthrift="0.18.1"
export zlib_ng="2.0"
export petsc="3.17"
export thrift_cpp="0.18.1"
export ffmpeg="4.4"
export mpfr="4"
export libabseil_static="20220623.0"
export tbb="2021"
export libexactreal="3"
export aws_checksums="0.1.14"
export llvm_openmp="15"
export aws_c_http="0.7.7"
export nspr="4"
export libxsmm="1"
export pytorch="1.13"
export gf2x="1.3"
export ipopt="3.14.11"
export zlib="1.2"
export poppler="22.12"
export cfitsio="4.1.0"
export pybind11_abi="4"
export libgoogle_cloud="2.10.0"
export rust_compiler="rust"
export dcap="2.47"
export mkl_devel="2022"
export libflint="2.9"
export nettle="3.8"
export libpq="15"
export tk="8.6"
export gflags="2.2"
export libspatialindex="1.9.3"
export gdk_pixbuf="2"
export harfbuzz="6"
export qt="5.12"
export aws_c_mqtt="0.8.6"
export c_ares="1"
export libarchive="3.6"
export netcdf_cxx4="4.3"
export macos_machine="x86_64-apple-darwin13.4.0"
export cran_mirror="https://cran.r-project.org"
export vtk="9.2.5"
export libgrpc="1.52"
export googleapis_cpp="0.10"
export libsndfile="1.2"
export target_gobin="${PREFIX}/bin/"
export aom="3.5"
export ccr="1.3"
export imath="3.1.7"
export graphviz="8"
export mumps_seq="5.2.1"
export assimp="5.2.5"
export capnproto="0.10.2"
export antic="0.2"
export x265="3.5"
export xz="5"
export libzip="1"
export mpich="4"
export postgresql="15"
export dbus="1"
export boost="1.78.0"
export petsc4py="3.17"
export libffi="3.4"
export pcl="1.13.0"
export libsqlite="3"
export gsoap="2.8.123"
export google_cloud_cpp_common="0.25.0"
export libiconv="1"
export libwebp="1"
export libev="4.33"
export openjpeg="2"
export target_goos="darwin"
export glew="2.1"
export sqlite="3"
export mimalloc="2.1.1"
export mumps_mpi="5.2.1"
export libopencv="4.7.0"
export fontconfig="2"
export libunwind="1.6"
export libsecret="0.18"
export giflib="5.2"
export coin_or_utils="2.11"
export icu="70"
export pango="1.50"
export expat="2"
export ptscotch="6.0.9"
export gnutls="3.7"
export fftw="3"
export rocksdb="6.10"
export qtkeychain="0.13"
export jsoncpp="1.9.5"
export coin_or_clp="1.17"
export openexr="3.1"
export libavif="0.11.1"
export uhd="4.4.0"
export openblas="0.3.*"
export geos="3.11.1"
export openturns="1.20"
export sdl2_net="2"
export liblapack="3.9 *netlib"
export x264="1!164.*"
export elfutils="0.189"
export c_compiler="clang"
export glib="2"
export metis="5.1"
export xrootd="5"
export cpu_optimization_target="nocona"
export aws_c_auth="0.6.26"
export glpk="5.0"
export librsvg="2"
export libraw="0.21"
export pcre="8"
export libmicrohttpd="0.9"
export fortran_compiler="gfortran"
export suitesparse="5"
export curl="8"
export p11_kit="0.24"
export sdl2_mixer="2"
export slepc="3.17"
export libgit2="1.6"
export gst_plugins_base="1.22"
export sdl2="2"
export libuuid="2"
export flann="1.9.1"
export sdl2_image="2"
export pulseaudio="16.1"
export soapysdr="0.8"
export zstd="1.5"
export openh264="2.3.1"
export urdfdom="3.1"
export libnetcdf="4.8.1"
export postgresql_plpython="15"
export libintervalxt="3"
export openmpi="4"
export libcint="5.2"
export VERBOSE_CM="VERBOSE=1"
export ruby="2.6"
export lzo="2"
export cuda_compiler_version="None"
export bamtools="2.5.1"
export gfal2="2.21"
export tinyxml2="9"
export cgo_compiler="go-cgo"
export jasper="2"
export tbb_devel="2021"
export libvips="8"
export hdf5="1.12.2"
export arb="2.23"
export libevent="2.1.10"
export aws_c_event_stream="0.2.20"
export cuda_compiler_version_min="None"
export ucx="1.14.0"
export openssl="3"
export glog="0.6"
export libpng="1.6"
export jpeg="9"
export console_bridge="1.0"
export krb5="1.19"
export readline="8"
export scotch="6.0.9"
export pari="2.15.* *_pthread"
export aws_c_io="0.13.21"
export libprotobuf="3.21"
export alsa_lib="1.2.8"
export go_compiler="go-nocgo"
export nss="3"
export libkml="1.3"
export aws_c_s3="0.2.8"
export davix="0.8"
export gstreamer="1.22"
export libblas="3.9 *netlib"
export nodejs="16"
export proj="9.1.0"
export poco="1.12.4"
export libidn2="2"
export isl="0.25"
export cudnn="undefined"
export ntl="11.4.3"
export nlopt="2.7"
export arpack="3.7"
export grpc_cpp="1.52"
export fmt="9"
export libv8="8.9.83"
export libhwy="1.0"
export json_c="0.16"
export _libgcc_mutex="0.1 conda_forge"
export abseil_cpp="20220623.0"
export channel_targets="bioconda main"
export libxml2="2.11.*"
export aws_c_sdkutils="0.1.9"
export svt_av1="1.4.1"
export nccl="2"
export libabseil="20230125"
export libgdal="3.6"
export libeantic="1"
export libaec="1"
export hdf4="4.2.15"
export liblapacke="3.9 *netlib"
export aws_crt_cpp="0.19.9"
export target_platform="osx-64"
export freetype="2"
export libssh="0.10"
export spdlog="1.11"
export gnuradio_core="3.10.6"
export libsvm="325"
export eclib="20230424"
export libhugetlbfs="2"
export exiv2="0.27"
export slepc4py="3.17"
export libcurl="8"
export ncurses="6"
export re2="2023.02.02"
export libjpeg_turbo="2"
export pixman="0"
export aws_c_common="0.8.17"
export libblitz="1.0.2"
export xerces_c="3.2"
export cxx_compiler="clangxx"
export log4cxx="0.11.0"
export google_cloud_cpp="2.10.0"
export attr="2.5"
export libwebp_base="1"
export gmp="6"
export libcblas="3.9 *netlib"
export libssh2="1"
export s2n="1.3.42"
export gsl="2.7"
export pcre2="10.40"
export wcslib="7.7"
export singular="4.2.1.p3"
export gct="6.2.1629922860"
export lz4_c="1.9.3"
export snappy="1"
export root_base="6.26.10"
export libpcap="1.10"
export coincbc="2.10"
export mpg123="1.31"
export lerc="4"
export wxwidgets="3.2"
export libsentencepiece="0.1.97"
export channel_sources="conda-forge,bioconda,defaults"
export zfp="1.0"
export libcrc32c="1.1"
export VERBOSE_AT="V=1"
export libmatio="1.5.21"
export vlfeat="0.9.21"
export boost_cpp="1.78.0"
export bzip2="1"
export lcms="2"
export blas_impl="blis"
export sox="14.4.2"
export coin_or_osi="0.108"
export libiio="0"
export libdap4="3.20.6"
export r_base="4.3.*"
export aws_sdk_cpp="1.10.57"
export libtiff="4.4"
export mkl="2022"
export coin_or_cbc="2.10"
export netcdf_fortran="4.5"
export target_goarch="amd64"
export orc="1.8.3"
export gdal="3.6"
export sdl2_ttf="2"
export coin_or_cgl="0.60"
export librdkafka="1.9"
export starlink_ast="9.2.7"
export cuda_compiler="None"
export zeromq="4.3.4"
export tiledb="2.13"
export aws_c_cal="0.5.26"
export cairo="1"
export occt="7.7"
export libflatsurf="3"
export kealib="1.5"
export superlu_dist="7.1.1"
export geotiff="1.7.1"
export python_impl="cpython"
export libarrow="11.0.0"
export arrow_cpp="11.0.0"
export fortran_compiler_version="12"
export cxx_compiler_version="15"
export c_compiler_version="15"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/mambaforge/envs/bioconda/bin/python3.8' -m conda shell.bash hook)"
conda activate  "/opt/mambaforge/envs/bioconda/conda-bld/earlgrey_1702288736476/_build_env"
